from dataclasses import dataclass
from urllib.parse import ParseResult
import logging

from microkodi.helpers import KodiTime


@dataclass
class PlayerInfo:
    runtime: int
    position: int
    title: str
    playing: bool


class Program:
    logger: logging.Logger

    def __init__(self):
        self.logger = logging.getLogger(self.__class__.__name__)

    def is_active(self) -> bool:
        raise NotImplementedError()

    def is_playing(self) -> bool:
        raise NotImplementedError()

    def play(self, url: ParseResult):
        raise NotImplementedError()

    def resume(self):
        raise NotImplementedError()

    def pause(self):
        raise NotImplementedError()

    def stop(self):
        raise NotImplementedError()

    def exit(self):
        raise NotImplementedError()

    def get_player_info(self) -> PlayerInfo:
        raise NotImplementedError()

    def seek(self, timestamp: KodiTime):
        raise NotImplementedError()
